Package: ryandexdirect
Type: Package
Title: Load Data From 'Yandex Direct'
Version: 3.6.6
Description: Load data from 'Yandex Direct' API V5 
    <https://yandex.ru/dev/direct/doc/dg/concepts/about-docpage> into R.
	Provide function for load lists of campaings, ads, keywords and other 
	objects from 'Yandex Direct' account. Also you can load statistic from
	API 'Reports Service' <https://yandex.ru/dev/direct/doc/reports/reports-docpage>.
	And allows keyword bids management.
License: GPL-2
Authors@R: 
    c(person(given  = "Alexey",
             family = "Seleznev",
             role   = c("aut", "cre"),
             email  = "selesnow@gmail.com",
             comment = c(ORCID = "0000-0003-0410-7385")))
Author: Alexey Seleznev [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0410-7385>)
Maintainer: Alexey Seleznev <selesnow@gmail.com>
Depends: R (>= 3.5.0)
BugReports: https://github.com/selesnow/ryandexdirect/issues
URL: https://selesnow.github.io/ryandexdirect/,
        https://t.me/R4marketing,
        https://www.youtube.com/playlist?list=PLD2LDq8edf4oUo0L9Kw77ZXf0KcV1hu67
Imports: utils, httr, bitops, jsonlite, xml2, data.table, readr,
        magrittr, dplyr, tidyr (>= 1.0.0), purrr, stringr, httr2
Suggests: knitr, rmarkdown, kableExtra, googleAnalyticsR, rym
Encoding: UTF-8
Language: ru
VignetteBuilder: knitr
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-05-19 19:33:05 UTC; User
Repository: CRAN
Date/Publication: 2026-05-20 06:20:15 UTC
Built: R 4.5.2; ; 2026-05-21 23:34:28 UTC; unix
