export(yadirGetCampaignList)
export(yadirGetCampaign)
export(yadirGetClientList)
export(yadirGetToken)
export(yadirAuth)
export(yadirGetLogins)
export(yadirSetLogin)
export(yadirSetAgencyAccount)
export(yadirGetDictionary)
export(yadirCurrencyRates)
export(yadirGetReport)
export(yadirGetAdGroups)
export(yadirGetAds)
export(yadirGetKeyWords)
export(yadirGetBalance)
export(yadirGetClientParam)
export(yadirGetSiteLinks)
export(yadirStopCampaigns)
export(yadirStartCampaigns)
export(yadirStartAds)
export(yadirStopAds)
export(yadirStopKeyWords)
export(yadirStartKeyWords)
export(yadirGetKeyWordsBids)
export(yadirSetAutoKeyWordsBids)
export(yadirGetWordStatReport)
export(yadirSetKeyWordsBids)
export(yadirGetForecast)
export(yadirGetCostData)
importFrom(utils,browseURL)
importFrom(utils,head)
importFrom(httr,POST)
importFrom(httr,GET)
importFrom(httr,stop_for_status)
importFrom(httr,content)
importFrom(httr,add_headers)
importFrom(httr, headers)
importFrom(tidyr, unnest_wider, unnest_longer, hoist, replace_na)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,fromJSON)
importFrom(xml2,xml_text)
importFrom(xml2,xml_find_all)
importFrom(dplyr, bind_rows, select, filter, tibble, rename, mutate, mutate_if, "%>%")
importFrom(purrr, map_df, map_dfr, flatten)
importFrom(stringr, str_glue)
import(bitops)
import(data.table)
import(magrittr)
import(httr2)
importFrom(httr2, request, req_body_form, req_perform, req_url_query, req_headers, resp_body_json)
importFrom(xml2, xml_find_all)
importFrom(xml2, xml_text)
import(readr)
S3method(print, yadir_token)
